# pictograms-buildings

## Dépendances
```shell
pictograms-buildings
└─ core
```

## Utilisation
Afin d’utiliser le composant `pictograms-buildings`, il est nécessaire d’ajouter les fichiers de styles et de scripts présents dans le dossier dist dans l'ordre suivant :\n
```html
<html>
  <head>
    <link href="css/core/core.min.css" rel="stylesheet">
  </head>
  <body>
  </body>
</html>
```